#!/usr/bin/perl
# $Id: db_checkpoint.pl,v 1.1 2001/12/11 02:00:20 pbaltz Exp $
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
#
# Try to run db_checkpoint on the user and group db environment, so dbrecover
# doesn't take so long to check the database consistency on system
# boot.  Also, use db_archive to find out which log files are no longer needed
# and remove old log files from the system to save disk space.

use lib qw(/usr/sausalito/perl);
use I18n;

my $DB_CHECKPOINT = '/usr/bin/db_checkpoint';
my $DB_ARCHIVE = '/usr/bin/db_archive';
my $DB_HOME = '/var/db';
my $DB_LOGFILE = '/var/log/dbrecover.log';

# try to checkpoint the db twice.
# Checkpoint it twice so that db_recover uses the first checkpoint to
# start recovery, so it will finish relatively quickly.
for (my $i = 0; $i < 2; $i++)
{
	system("$DB_CHECKPOINT -1 -v -h $DB_HOME >>$DB_LOGFILE 2>&1");

	# check if it succeeded
	if ($?)
	{
		# failed for some reason
		my $locale = I18n::i18n_getSystemLocale();
		my $i18n = new I18n;
		$i18n->setLocale($locale);
		print $i18n->get('[[base-sys.checkPointFailed]]');
		exit(1);
	}
}

# no run db_archive to see what we can clean up
my @old_logs = `$DB_ARCHIVE -h $DB_HOME 2>/dev/null`;
chomp(@old_logs);

for my $file (@old_logs)
{
	unlink("$DB_HOME/$file");
}

exit(0);
